@@ -1,4 +1,5 @@
 from django.contrib import admin
+from django.utils.translation import ugettext_lazy as _
 
 from models import Notification
 
@@ -7,7 +8,7 @@ class NotificationAdmin(admin.ModelAdmin):
     date_hierarchy = 'created'
     list_display = ['id', 'transaction_id', 'result', 'amount_and_currency', 'reference', 'signature',
                     #'trustpay_signature', 'merchant_signature',
-                    'is_test', 'is_signed', 'is_safe', 'created']
+                    'is_live', 'is_signed', 'is_safe', 'created']
     list_filter = ['result', 'currency', 'is_test', 'is_signed', 'is_safe',]
     search_fields = ['params_get', 'params_post']
 
@@ -17,6 +18,10 @@ class NotificationAdmin(admin.ModelAdmin):
     def amount_and_currency(self, obj):
         return u'%s %s' % (obj.amount, obj.currency)
 
+    def is_live(self, obj):
+        return not obj.is_test
+    is_live.boolean = True
+    is_live.short_description = _(u'Live')
 
 admin.site.register(Notification, NotificationAdmin)
 
